@@ -26,6 +26,7 @@ mod param;
 mod response;
 
 pub struct Operation {
+    pub deprecated: bool,
     pub id: Option<LitStr>,
     pub path: LitStr,
     pub method: Ident,
@@ -45,6 +46,7 @@ impl Operation {
             _ => abort!(Span::call_site(), "function expected"),
         };
 
+        let mut deprecated = false;
         let mut params: Vec<Param> = Vec::new();
         let mut responses = Vec::new();
         let mut default_response: Option<DefaultResponse> = None;
@@ -92,6 +94,8 @@ impl Operation {
                                 }
                             },
                         }
+                    } else if name == "deprecated" {
+                        deprecated = true;
                     } else if name == "param" || name == "parameter" {
                         match value.parse_with(|input: ParseStream| input.parse::<Param>()) {
                             Ok(r) => {
@@ -210,8 +214,6 @@ impl Operation {
             } else {
                 true
             }
-
-            // false
         });
 
         if method.is_none() {
@@ -279,6 +281,7 @@ impl Operation {
 
         match errors {
             None => Ok(Self {
+                deprecated,
                 item: item_fn,
                 id,
                 tags,
@@ -492,7 +495,9 @@ impl Operation {
         )
     }
 
+    #[allow(clippy::too_many_arguments)]
     fn gen_operation(
+        deprecated: bool,
         id: &LitStr,
         crate_name: TokenStream,
         doc: Option<&LitStr>,
@@ -587,6 +592,7 @@ impl Operation {
                         },
                         content: Box::new(
                             #crate_name::openapi::v3::gen::item::ItemOperation {
+                                deprecated: #deprecated,
                                 #op_fields
                             }
                         )
@@ -1145,6 +1151,7 @@ impl ToTokens for Operation {
         let path = &self.path;
 
         let op = Operation::gen_operation(
+            self.deprecated,
             &id,
             crate_name.clone(),
             doc,
